diff --git a/src/OpenFOAM/db/IOstreams/IOstreams/IOstreamOption.H b/src/OpenFOAM/db/IOstreams/IOstreams/IOstreamOption.H
index b1ae05ac4fa2d2b78797fc6ce624de7c3ed322de..e952058dc46fec2e7a4ffaaf624a72ff2fb49660 100644
--- a/src/OpenFOAM/db/IOstreams/IOstreams/IOstreamOption.H
+++ b/src/OpenFOAM/db/IOstreams/IOstreams/IOstreamOption.H
@@ -42,8 +42,8 @@ SourceFiles
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef IOstreamOption_H
-#define IOstreamOption_H
+#ifndef Foam_IOstreamOption_H
+#define Foam_IOstreamOption_H
 
 #include "word.H"
 
diff --git a/src/OpenFOAM/db/dictionary/dictionaryContent/dictionaryContent.H b/src/OpenFOAM/db/dictionary/dictionaryContent/dictionaryContent.H
index c1137f1eef17b14c32cf3689634a101df5be436b..2d5ed67ea17d0ffd28192c511e4b7247980b3366 100644
--- a/src/OpenFOAM/db/dictionary/dictionaryContent/dictionaryContent.H
+++ b/src/OpenFOAM/db/dictionary/dictionaryContent/dictionaryContent.H
@@ -32,10 +32,11 @@ Description
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef dictionaryContent_H
-#define dictionaryContent_H
+#ifndef Foam_dictionaryContent_H
+#define Foam_dictionaryContent_H
 
 #include "dictionary.H"
+#include "wordList.H"
 #include "wordRes.H"
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
diff --git a/src/OpenFOAM/expressions/exprResult/exprResult.C b/src/OpenFOAM/expressions/exprResult/exprResult.C
index 296cb3f7b9d6dcc84b23ecd01707b8bd3a065c19..5b013566ed006023c5f24a0561dbf1741bb5a276 100644
--- a/src/OpenFOAM/expressions/exprResult/exprResult.C
+++ b/src/OpenFOAM/expressions/exprResult/exprResult.C
@@ -254,8 +254,11 @@ Foam::expressions::exprResult::exprResult
 {
     DebugInFunction << nl;
 
-    if (dict.found("value"))
+    const auto* hasValue = dict.findEntry("value", keyType::LITERAL);
+
+    if (hasValue)
     {
+        const auto& valueEntry = *hasValue;
         const bool uniform = isUniform_;
 
         const label len =
@@ -268,12 +271,12 @@ Foam::expressions::exprResult::exprResult
         const bool ok =
         (
             // Just use <scalar> for <label>?
-            readChecked<scalar>("value", dict, len, uniform)
-         || readChecked<vector>("value", dict, len, uniform)
-         || readChecked<tensor>("value", dict, len, uniform)
-         || readChecked<symmTensor>("value", dict, len, uniform)
-         || readChecked<sphericalTensor>("value", dict, len, uniform)
-         || readChecked<bool>("value", dict, len, uniform)
+            readChecked<scalar>(valueEntry, len, uniform)
+         || readChecked<vector>(valueEntry, len, uniform)
+         || readChecked<tensor>(valueEntry, len, uniform)
+         || readChecked<symmTensor>(valueEntry, len, uniform)
+         || readChecked<sphericalTensor>(valueEntry, len, uniform)
+         || readChecked<bool>(valueEntry, len, uniform)
         );
 
         if (!ok)
diff --git a/src/OpenFOAM/expressions/exprResult/exprResultI.H b/src/OpenFOAM/expressions/exprResult/exprResultI.H
index eb771176f6711f633baf6f339eb84d3dcbab914f..64eb52c70eae16022a53f96659ea7bc75dc9492a 100644
--- a/src/OpenFOAM/expressions/exprResult/exprResultI.H
+++ b/src/OpenFOAM/expressions/exprResult/exprResultI.H
@@ -6,7 +6,7 @@
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
     Copyright (C) 2012-2018 Bernhard Gschaider
-    Copyright (C) 2019-2021 OpenCFD Ltd.
+    Copyright (C) 2019-2022 OpenCFD Ltd.
 -------------------------------------------------------------------------------
 License
     This file is part of OpenFOAM.
@@ -82,8 +82,7 @@ inline bool Foam::expressions::exprResult::deleteChecked()
 template<class Type>
 inline bool Foam::expressions::exprResult::readChecked
 (
-    const word& key,
-    const dictionary& dict,
+    const entry& e,
     const label len,
     const bool uniform
 )
@@ -96,7 +95,7 @@ inline bool Foam::expressions::exprResult::readChecked
 
         if (uniform)
         {
-            const Type val(dict.get<Type>(key));
+            const Type val(e.get<Type>());
 
             size_ = len;
             fieldPtr_ = new Field<Type>(size_, val);
@@ -106,7 +105,7 @@ inline bool Foam::expressions::exprResult::readChecked
         else
         {
             size_ = len;
-            fieldPtr_ = new Field<Type>(key, dict, size_);
+            fieldPtr_ = new Field<Type>(e, size_);
         }
 
         isUniform_ = uniform;
diff --git a/src/OpenFOAM/fields/pointPatchFields/basic/value/valuePointPatchField.C b/src/OpenFOAM/fields/pointPatchFields/basic/value/valuePointPatchField.C
index 775710af1545f96eaccdd6ec41393c4fb7adc162..f9eacfb3befb56f05c376d6d7a744794aa177f90 100644
--- a/src/OpenFOAM/fields/pointPatchFields/basic/value/valuePointPatchField.C
+++ b/src/OpenFOAM/fields/pointPatchFields/basic/value/valuePointPatchField.C
@@ -55,11 +55,11 @@ Foam::valuePointPatchField<Type>::valuePointPatchField
     pointPatchField<Type>(p, iF, dict),
     Field<Type>(p.size())
 {
-    const auto* eptr = dict.findEntry("value", keyType::LITERAL);
+    const auto* hasValue = dict.findEntry("value", keyType::LITERAL);
 
-    if (eptr)
+    if (hasValue)
     {
-        Field<Type>::assign(*eptr, p.size());
+        Field<Type>::assign(*hasValue, p.size());
     }
     else if (!valueRequired)
     {
diff --git a/src/OpenFOAM/interpolations/uniformInterpolationTable/uniformInterpolationTable.H b/src/OpenFOAM/interpolations/uniformInterpolationTable/uniformInterpolationTable.H
index 09e2275b4a1e095932bb660bbcf68a9d8cbaf3a7..cc50083452f7e104e73fbdbc555889b17411cc91 100644
--- a/src/OpenFOAM/interpolations/uniformInterpolationTable/uniformInterpolationTable.H
+++ b/src/OpenFOAM/interpolations/uniformInterpolationTable/uniformInterpolationTable.H
@@ -139,10 +139,10 @@ public:
             inline scalar dx() const;
 
             //- Return the log10(x) flag
-            inline const Switch& log10() const;
+            inline Switch log10() const noexcept;
 
             //- Return the bound flag
-            inline const Switch& bound() const;
+            inline Switch bound() const noexcept;
 
 
         // Edit
@@ -154,10 +154,10 @@ public:
             inline scalar& dx();
 
             //- Return the log10(x) flag
-            inline Switch& log10();
+            inline Switch& log10() noexcept;
 
             //- Return the bound flag
-            inline Switch& bound();
+            inline Switch& bound() noexcept;
 
 
         // Evaluation
diff --git a/src/OpenFOAM/interpolations/uniformInterpolationTable/uniformInterpolationTableI.H b/src/OpenFOAM/interpolations/uniformInterpolationTable/uniformInterpolationTableI.H
index 66aff95bee539e5bad7c0735b4afe0734f7f8016..032a2a86cfe19fcae13512f89ef1215b8066816f 100644
--- a/src/OpenFOAM/interpolations/uniformInterpolationTable/uniformInterpolationTableI.H
+++ b/src/OpenFOAM/interpolations/uniformInterpolationTable/uniformInterpolationTableI.H
@@ -40,14 +40,14 @@ Foam::scalar Foam::uniformInterpolationTable<Type>::dx() const
 
 
 template<class Type>
-const Foam::Switch& Foam::uniformInterpolationTable<Type>::log10() const
+Foam::Switch Foam::uniformInterpolationTable<Type>::log10() const noexcept
 {
     return log10_;
 }
 
 
 template<class Type>
-const Foam::Switch& Foam::uniformInterpolationTable<Type>::bound() const
+Foam::Switch Foam::uniformInterpolationTable<Type>::bound() const noexcept
 {
     return bound_;
 }
@@ -68,14 +68,14 @@ Foam::scalar& Foam::uniformInterpolationTable<Type>::dx()
 
 
 template<class Type>
-Foam::Switch& Foam::uniformInterpolationTable<Type>::log10()
+Foam::Switch& Foam::uniformInterpolationTable<Type>::log10() noexcept
 {
     return log10_;
 }
 
 
 template<class Type>
-Foam::Switch& Foam::uniformInterpolationTable<Type>::bound()
+Foam::Switch& Foam::uniformInterpolationTable<Type>::bound() noexcept
 {
     return bound_;
 }
diff --git a/src/OpenFOAM/primitives/bools/Switch/Switch.C b/src/OpenFOAM/primitives/bools/Switch/Switch.C
index e8bac8c15ea161bb9cc9a78527e7020118307a60..36a4647b3d89b2c46e29cc113cb45cd8990f6240 100644
--- a/src/OpenFOAM/primitives/bools/Switch/Switch.C
+++ b/src/OpenFOAM/primitives/bools/Switch/Switch.C
@@ -6,7 +6,7 @@
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
     Copyright (C) 2011-2016 OpenFOAM Foundation
-    Copyright (C) 2017-2020 OpenCFD Ltd.
+    Copyright (C) 2017-2022 OpenCFD Ltd.
 -------------------------------------------------------------------------------
 License
     This file is part of OpenFOAM.
@@ -364,7 +364,7 @@ Foam::Istream& Foam::operator>>(Istream& is, Switch& sw)
 }
 
 
-Foam::Ostream& Foam::operator<<(Ostream& os, const Switch& sw)
+Foam::Ostream& Foam::operator<<(Ostream& os, const Switch sw)
 {
     os << sw.c_str();
     return os;
diff --git a/src/OpenFOAM/primitives/bools/Switch/Switch.H b/src/OpenFOAM/primitives/bools/Switch/Switch.H
index 067e208d88d24d13423935306d41955f1f5fc82c..b6e44fe89bebae9509dd7f5d622aedceb2b93c09 100644
--- a/src/OpenFOAM/primitives/bools/Switch/Switch.H
+++ b/src/OpenFOAM/primitives/bools/Switch/Switch.H
@@ -6,7 +6,7 @@
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
     Copyright (C) 2011-2016 OpenFOAM Foundation
-    Copyright (C) 2017-2020 OpenCFD Ltd.
+    Copyright (C) 2017-2022 OpenCFD Ltd.
 -------------------------------------------------------------------------------
 License
     This file is part of OpenFOAM.
@@ -37,8 +37,8 @@ SourceFiles
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef Switch_H
-#define Switch_H
+#ifndef Foam_Switch_H
+#define Foam_Switch_H
 
 #include "bool.H"
 #include "stdFoam.H"
@@ -69,7 +69,7 @@ class Switch;
 Istream& operator>>(Istream& is, Switch& sw);
 
 //- Write Switch to stream as its text value (eg, "true", "false")
-Ostream& operator<<(Ostream& is, const Switch& sw);
+Ostream& operator<<(Ostream& is, const Switch sw);
 
 /*---------------------------------------------------------------------------*\
                            Class Switch Declaration
@@ -130,19 +130,19 @@ public:
             value_(switchType::FALSE)
         {}
 
-        //- Construct from enumerated value
+        //- Implicit construct from enumerated value
         constexpr Switch(const switchType sw) noexcept
         :
             value_(sw)
         {}
 
-        //- Construct from bool
+        //- Implicit construct from bool
         constexpr Switch(const bool b) noexcept
         :
             value_(b ? switchType::TRUE : switchType::FALSE)
         {}
 
-        //- Construct from int (treat integer as bool value)
+        //- Implicit construct from int (treat integer as bool value)
         constexpr Switch(const int i) noexcept
         :
             value_(i ? switchType::TRUE : switchType::FALSE)
diff --git a/src/finiteArea/fields/faPatchFields/faPatchField/faPatchField.C b/src/finiteArea/fields/faPatchFields/faPatchField/faPatchField.C
index dc7a42400de5ac9a331e5525465a618b6bd1d2c4..60f7368ed85ca519054c5c98df1cc00ee1f7dc29 100644
--- a/src/finiteArea/fields/faPatchFields/faPatchField/faPatchField.C
+++ b/src/finiteArea/fields/faPatchFields/faPatchField/faPatchField.C
@@ -88,11 +88,11 @@ Foam::faPatchField<Type>::faPatchField
 {
     /// if (valueRequired) - not yet needed. Already a lazy evaluation
 
-    const auto* eptr = dict.findEntry("value", keyType::LITERAL);
+    const auto* hasValue = dict.findEntry("value", keyType::LITERAL);
 
-    if (eptr)
+    if (hasValue)
     {
-        Field<Type>::assign(*eptr, p.size());
+        Field<Type>::assign(*hasValue, p.size());
     }
     else
     {
diff --git a/src/finiteArea/fields/faePatchFields/faePatchField/faePatchField.C b/src/finiteArea/fields/faePatchFields/faePatchField/faePatchField.C
index 2c84b4ed5b4e7cb45ea4ab79ded9a84d42092120..c9c93d5af22de68cf42a19b1e62bccb2a1898b9d 100644
--- a/src/finiteArea/fields/faePatchFields/faePatchField/faePatchField.C
+++ b/src/finiteArea/fields/faePatchFields/faePatchField/faePatchField.C
@@ -85,11 +85,11 @@ Foam::faePatchField<Type>::faePatchField
     Field<Type>(p.size()),
     internalField_(iF)
 {
-    const auto* eptr = dict.findEntry("value", keyType::LITERAL);
+    const auto* hasValue = dict.findEntry("value", keyType::LITERAL);
 
-    if (eptr)
+    if (hasValue)
     {
-        Field<Type>::assign(*eptr, p.size());
+        Field<Type>::assign(*hasValue, p.size());
     }
     else
     {
diff --git a/src/finiteVolume/expressions/fields/fvPatchFields/exprFixedValueFvPatchField.C b/src/finiteVolume/expressions/fields/fvPatchFields/exprFixedValueFvPatchField.C
index 71fa7dc3916b47323399e1d20f419f62005410a9..97320176f17e075a60843aa91540e42535434be1 100644
--- a/src/finiteVolume/expressions/fields/fvPatchFields/exprFixedValueFvPatchField.C
+++ b/src/finiteVolume/expressions/fields/fvPatchFields/exprFixedValueFvPatchField.C
@@ -85,7 +85,7 @@ Foam::exprFixedValueFvPatchField<Type>::exprFixedValueFvPatchField
     const bool valueRequired
 )
 :
-    parent_bctype(p, iF),
+    parent_bctype(p, iF), // bypass dictionary constructor
     expressions::patchExprFieldBase
     (
         dict,
@@ -121,12 +121,15 @@ Foam::exprFixedValueFvPatchField<Type>::exprFixedValueFvPatchField
 
     driver_.readDict(dict_);
 
-    if (dict.found("value"))
+    // Similar to fvPatchField constructor, which we have bypassed
+    dict.readIfPresent("patchType", this->patchType(), keyType::LITERAL);
+
+
+    const auto* hasValue = dict.findEntry("value", keyType::LITERAL);
+
+    if (hasValue)
     {
-        fvPatchField<Type>::operator=
-        (
-            Field<Type>("value", dict, p.size())
-        );
+        Field<Type>::assign(*hasValue, p.size());
     }
     else
     {
diff --git a/src/finiteVolume/expressions/fields/fvPatchFields/exprMixedFvPatchField.C b/src/finiteVolume/expressions/fields/fvPatchFields/exprMixedFvPatchField.C
index 473b930cb91a9dc89cfeffe328551afed82bd605..45837a762a09af74cf1c426e4e2143efea3d8e8d 100644
--- a/src/finiteVolume/expressions/fields/fvPatchFields/exprMixedFvPatchField.C
+++ b/src/finiteVolume/expressions/fields/fvPatchFields/exprMixedFvPatchField.C
@@ -87,7 +87,7 @@ Foam::exprMixedFvPatchField<Type>::exprMixedFvPatchField
     const dictionary& dict
 )
 :
-    parent_bctype(p, iF),
+    parent_bctype(p, iF), // bypass dictionary constructor
     expressions::patchExprFieldBase
     (
         dict,
@@ -160,27 +160,32 @@ Foam::exprMixedFvPatchField<Type>::exprMixedFvPatchField
         }
     }
 
-
     driver_.readDict(dict_);
 
     // Similar to fvPatchField constructor, which we have bypassed
     dict.readIfPresent("patchType", this->patchType(), keyType::LITERAL);
 
-    bool needsRefValue = true;
-    if (dict.found("refValue"))
+
+    const auto* hasValue = dict.findEntry("value", keyType::LITERAL);
+    const auto* hasRefValue = dict.findEntry("refValue", keyType::LITERAL);
+
+    const auto* hasRefGradient
+        = dict.findEntry("refGradient", keyType::LITERAL);
+
+    const auto* hasValueFraction
+        = dict.findEntry("valueFraction", keyType::LITERAL);
+
+
+    if (hasRefValue)
     {
-        needsRefValue = false;
-        this->refValue() = Field<Type>("refValue", dict, p.size());
+        this->refValue().assign(*hasRefValue, p.size());
     }
 
-    if (dict.found("value"))
+    if (hasValue)
     {
-        fvPatchField<Type>::operator=
-        (
-            Field<Type>("value", dict, p.size())
-        );
+        Field<Type>::assign(*hasValue, p.size());
 
-        if (needsRefValue)
+        if (!hasRefValue)
         {
             // Ensure refValue has a sensible value for the "update" below
             this->refValue() = static_cast<const Field<Type>&>(*this);
@@ -188,7 +193,7 @@ Foam::exprMixedFvPatchField<Type>::exprMixedFvPatchField
     }
     else
     {
-        if (needsRefValue)
+        if (!hasRefValue)
         {
             this->refValue() = this->patchInternalField();
         }
@@ -204,18 +209,18 @@ Foam::exprMixedFvPatchField<Type>::exprMixedFvPatchField
     }
 
 
-    if (dict.found("refGradient"))
+    if (hasRefGradient)
     {
-        this->refGrad() = Field<Type>("refGradient", dict, p.size());
+        this->refGrad().assign(*hasRefGradient, p.size());
     }
     else
     {
         this->refGrad() = Zero;
     }
 
-    if (dict.found("valueFraction"))
+    if (hasValueFraction)
     {
-        this->valueFraction() = Field<scalar>("valueFraction", dict, p.size());
+        this->valueFraction().assign(*hasValueFraction, p.size());
     }
     else
     {
diff --git a/src/finiteVolume/expressions/fields/pointPatchFields/exprValuePointPatchField.C b/src/finiteVolume/expressions/fields/pointPatchFields/exprValuePointPatchField.C
index e813a07f1ecf4d1354fb889f385cb49e6194a225..6551b09b7aac65c595d1a5c07284536596f99c5e 100644
--- a/src/finiteVolume/expressions/fields/pointPatchFields/exprValuePointPatchField.C
+++ b/src/finiteVolume/expressions/fields/pointPatchFields/exprValuePointPatchField.C
@@ -6,7 +6,7 @@
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
     Copyright (C) 2010-2018 Bernhard Gschaider
-    Copyright (C) 2019-2021 OpenCFD Ltd.
+    Copyright (C) 2019-2022 OpenCFD Ltd.
 -------------------------------------------------------------------------------
 License
     This file is part of OpenFOAM.
@@ -85,7 +85,7 @@ Foam::exprValuePointPatchField<Type>::exprValuePointPatchField
     const dictionary& dict
 )
 :
-    parent_bctype(p, iF),
+    parent_bctype(p, iF),  // bypass dictionary constructor
     expressions::patchExprFieldBase
     (
         dict,
@@ -123,23 +123,20 @@ Foam::exprValuePointPatchField<Type>::exprValuePointPatchField
             << exit(FatalIOError);
     }
 
-
     driver_.readDict(dict_);
 
-    if (dict.found("value"))
+    const auto* hasValue = dict.findEntry("value", keyType::LITERAL);
+
+    if (hasValue)
     {
-        Field<Type>::operator=
-        (
-            Field<Type>("value", dict, p.size())
-        );
+        Field<Type>::assign(*hasValue, p.size());
     }
     else
     {
-        WarningInFunction
-            << "No value defined for "
-            << this->internalField().name()
-            << " on " << this->patch().name()
-            << endl;
+        // Note: valuePointPatchField defaults to Zero
+        // but internalField might be better
+
+        Field<Type>::operator=(Zero);
     }
 
     if (this->evalOnConstruct_)
diff --git a/src/finiteVolume/expressions/fields/pointPatchFields/exprValuePointPatchField.H b/src/finiteVolume/expressions/fields/pointPatchFields/exprValuePointPatchField.H
index 4ab37195de696ecdf65350cb721fc9c5993c5cf8..0c286e2028b94d2d2f2f460caf66f2ec1f994e83 100644
--- a/src/finiteVolume/expressions/fields/pointPatchFields/exprValuePointPatchField.H
+++ b/src/finiteVolume/expressions/fields/pointPatchFields/exprValuePointPatchField.H
@@ -41,8 +41,8 @@ SourceFiles
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef exprValuePointPatchField_H
-#define exprValuePointPatchField_H
+#ifndef Foam_exprValuePointPatchField_H
+#define Foam_exprValuePointPatchField_H
 
 #include "valuePointPatchField.H"
 #include "patchExprFieldBase.H"
diff --git a/src/finiteVolume/fields/fvPatchFields/fvPatchField/fvPatchField.C b/src/finiteVolume/fields/fvPatchFields/fvPatchField/fvPatchField.C
index 29eca05a696912c4b7aaf3dc4eea1d929fec651b..33d7d5fc30ac04b5be5ea8b63a9dead2d3d73061 100644
--- a/src/finiteVolume/fields/fvPatchFields/fvPatchField/fvPatchField.C
+++ b/src/finiteVolume/fields/fvPatchFields/fvPatchField/fvPatchField.C
@@ -104,11 +104,11 @@ Foam::fvPatchField<Type>::fvPatchField
 {
     if (valueRequired)
     {
-        const auto* eptr = dict.findEntry("value", keyType::LITERAL);
+        const auto* hasValue = dict.findEntry("value", keyType::LITERAL);
 
-        if (eptr)
+        if (hasValue)
         {
-            Field<Type>::assign(*eptr, p.size());
+            Field<Type>::assign(*hasValue, p.size());
         }
         else
         {
diff --git a/src/finiteVolume/fields/fvsPatchFields/fvsPatchField/fvsPatchField.C b/src/finiteVolume/fields/fvsPatchFields/fvsPatchField/fvsPatchField.C
index 5a3cbf105a13fd387e8aaf15c536d59edefc9a10..acb52ae74fa002c7affd4cc78c9a818bbdc86972 100644
--- a/src/finiteVolume/fields/fvsPatchFields/fvsPatchField/fvsPatchField.C
+++ b/src/finiteVolume/fields/fvsPatchFields/fvsPatchField/fvsPatchField.C
@@ -6,7 +6,7 @@
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
     Copyright (C) 2011-2015 OpenFOAM Foundation
-    Copyright (C) 2017 OpenCFD Ltd.
+    Copyright (C) 2017-2022 OpenCFD Ltd.
 -------------------------------------------------------------------------------
 License
     This file is part of OpenFOAM.
@@ -91,11 +91,11 @@ Foam::fvsPatchField<Type>::fvsPatchField
 {
     if (valueRequired)
     {
-        const auto* eptr = dict.findEntry("value", keyType::LITERAL);
+        const auto* hasValue = dict.findEntry("value", keyType::LITERAL);
 
-        if (eptr)
+        if (hasValue)
         {
-            Field<Type>::assign(*eptr, p.size());
+            Field<Type>::assign(*hasValue, p.size());
         }
         else
         {
diff --git a/src/regionFaModels/derivedFvPatchFields/filmShell/velocityFilmShellFvPatchVectorField.C b/src/regionFaModels/derivedFvPatchFields/filmShell/velocityFilmShellFvPatchVectorField.C
index f4923c446984c020162bf9cb4e858ae6eef8deeb..c5c8ace431f818aa3e5ab818f026ad24c1e25bb5 100644
--- a/src/regionFaModels/derivedFvPatchFields/filmShell/velocityFilmShellFvPatchVectorField.C
+++ b/src/regionFaModels/derivedFvPatchFields/filmShell/velocityFilmShellFvPatchVectorField.C
@@ -91,8 +91,8 @@ velocityFilmShellFvPatchVectorField::velocityFilmShellFvPatchVectorField
         dictionaryContent::copyDict
         (
             dict,
-            wordRes(),  // allow
-            wordRes     // deny
+            wordList(),  // allow
+            wordList     // deny
             ({
                 "type",  // redundant
                 "value", "refValue", "refGradient", "valueFraction"
diff --git a/src/regionFaModels/derivedFvPatchFields/thermalShell/thermalShellFvPatchScalarField.C b/src/regionFaModels/derivedFvPatchFields/thermalShell/thermalShellFvPatchScalarField.C
index 03dee9ea2e388e9742094614ebfd15e78048a214..f778792db8c9bb914d8ffec75613792ab846cb5e 100644
--- a/src/regionFaModels/derivedFvPatchFields/thermalShell/thermalShellFvPatchScalarField.C
+++ b/src/regionFaModels/derivedFvPatchFields/thermalShell/thermalShellFvPatchScalarField.C
@@ -85,8 +85,8 @@ thermalShellFvPatchScalarField::thermalShellFvPatchScalarField
         dictionaryContent::copyDict
         (
             dict,
-            wordRes(),  // allow
-            wordRes     // deny
+            wordList(),  // allow
+            wordList     // deny
             ({
                 "type",  // redundant
                 "value"
diff --git a/src/regionFaModels/derivedFvPatchFields/vibrationShell/vibrationShellFvPatchScalarField.C b/src/regionFaModels/derivedFvPatchFields/vibrationShell/vibrationShellFvPatchScalarField.C
index 71ca05eca46755812df0d82fa181c2ef2c067d2e..508bdbfa960edf54f2351f7bb2aeedf5d91a376a 100644
--- a/src/regionFaModels/derivedFvPatchFields/vibrationShell/vibrationShellFvPatchScalarField.C
+++ b/src/regionFaModels/derivedFvPatchFields/vibrationShell/vibrationShellFvPatchScalarField.C
@@ -87,8 +87,8 @@ vibrationShellFvPatchScalarField::vibrationShellFvPatchScalarField
         dictionaryContent::copyDict
         (
             dict,
-            wordRes(),  // allow
-            wordRes     // deny
+            wordList(),  // allow
+            wordList     // deny
             ({
                 "type",  // redundant
                 "value", "refValue", "refGradient", "valueFraction"
diff --git a/src/OpenFOAM/expressions/exprResult/exprResult.H b/src/OpenFOAM/expressions/exprResult/exprResult.H
index 793381351fdf47090d09a582912eea8ea2a8b66b..c570f1569e6a4fd05fc3b2e2897a2a177c6e4262 100644
--- a/src/OpenFOAM/expressions/exprResult/exprResult.H
+++ b/src/OpenFOAM/expressions/exprResult/exprResult.H
@@ -6,7 +6,7 @@
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
     Copyright (C) 2012-2018 Bernhard Gschaider
-    Copyright (C) 2019-2021 OpenCFD Ltd.
+    Copyright (C) 2019-2022 OpenCFD Ltd.
 -------------------------------------------------------------------------------
 License
     This file is part of OpenFOAM.
@@ -54,8 +54,8 @@ SourceFiles
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef expressions_exprResult_H
-#define expressions_exprResult_H
+#ifndef Foam_expressions_exprResult_H
+#define Foam_expressions_exprResult_H
 
 #include "exprTraits.H"
 #include "dimensionedType.H"
@@ -156,13 +156,12 @@ class exprResult
         //- Dispatch to type-checked pointer deletion
         void uglyDelete();
 
         //- Type-checked creation of field from dictionary
         //  \return True if the type check was satisfied
         template<class Type>
         inline bool readChecked
         (
-            const word& key,
-            const dictionary& dict,
+            const entry& e,
             const label len,
             const bool uniform
         );
@@ -156,13 +156,12 @@ class exprResult
         void uglyDelete();
 
-        //- Type-checked creation of field from dictionary
+        //- Type-checked creation of field from dictionary (primitive) entry
         //  \return True if the type check was satisfied
         template<class Type>